==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF03S.sql <==
/****************************************************************************/
/* GF03 ( ﾃｰﾌﾞﾙｶﾗﾑ定義ﾏｽﾀ )                                                 */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF03 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , CLM              VARCHAR2 (   30 )                   NOT NULL            /*  20 項目         */
 , NAME_JA          VARCHAR2 (  200 )                                       /*  30 名称         */
 , CLS_NAME         VARCHAR2 (   10 )                   NOT NULL            /*  40 DBｸﾗｽ        */
 , USE_LENGTH       VARCHAR2 (    9 )       DEFAULT '0'                     /*  50 使用桁数     */
 , DATA_DEFAULT     VARCHAR2 (  200 )                                       /*  60 初期値       */
 , FGIMP            VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /*  70 重要度       */
 , RENDERER         VARCHAR2 (   10 )                                       /*  80 表示種別     */
 , EDITOR           VARCHAR2 (   10 )                                       /*  90 編集種別     */
 , DBTYPE           VARCHAR2 (   10 )                                       /* 100 文字種別     */
 , RENDERER_PARAM   VARCHAR2 (  200 )                                       /* 110 表示ﾊﾟﾗﾒｰﾀ   */
 , EDITOR_PARAM     VARCHAR2 (  200 )                                       /* 120 編集ﾊﾟﾗﾒｰﾀ   */
 , TYPE_PARAM       VARCHAR2 (  200 )                                       /* 130 文字ﾊﾟﾗﾒｰﾀ   */
 , BIKO             VARCHAR2 ( 2000 )                                       /* 140 備考         */
 , SEQNO            NUMBER   (    7 )       DEFAULT 0   NOT NULL            /* 150 表示順       */
 , CDKH             VARCHAR2 (    1 )                                       /* 160 改廃ｺｰﾄﾞ     */
 , UNIQ             NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF03S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF03T00 
  BEFORE INSERT ON GF03
  FOR EACH ROW 
  BEGIN 
    SELECT GF03S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.2.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF03S.sql <==
/****************************************************************************/
/* GF03 ( ﾃｰﾌﾞﾙｶﾗﾑ定義ﾏｽﾀ )                                                 */
/*                                                                          */
/* Created : 2016/01/07 17:07:19                                            */
/****************************************************************************/
CREATE TABLE GF03 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , CLM              VARCHAR2 (   30 )                   NOT NULL            /*  20 項目         */
 , NAME_JA          VARCHAR2 (  200 )                                       /*  30 名称         */
 , CLS_NAME         VARCHAR2 (   10 )                   NOT NULL            /*  40 DBｸﾗｽ        */
 , USE_LENGTH       VARCHAR2 (    9 )       DEFAULT '0'                     /*  50 使用桁数     */
 , DATA_DEFAULT     VARCHAR2 (  200 )                                       /*  60 初期値       */
 , FGIMP            VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /*  70 重要度       */
 , RENDERER         VARCHAR2 (   10 )                                       /*  80 表示種別     */
 , EDITOR           VARCHAR2 (   10 )                                       /*  90 編集種別     */
 , DBTYPE           VARCHAR2 (   10 )                                       /* 100 文字種別     */
 , RENDERER_PARAM   VARCHAR2 (  200 )                                       /* 110 表示ﾊﾟﾗﾒｰﾀ   */
 , EDITOR_PARAM     VARCHAR2 (  200 )                                       /* 120 編集ﾊﾟﾗﾒｰﾀ   */
 , TYPE_PARAM       VARCHAR2 (  200 )                                       /* 130 文字ﾊﾟﾗﾒｰﾀ   */
 , BIKO             VARCHAR2 ( 2000 )                                       /* 140 備考         */
 , SEQNO            NUMBER   (    7 )       DEFAULT 0   NOT NULL            /* 150 表示順       */
 , CDKH             VARCHAR2 (    1 )                                       /* 160 改廃ｺｰﾄﾞ     */
 , UNIQ             NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF03S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF03T00 
  BEFORE INSERT ON GF03
  FOR EACH ROW 
  BEGIN 
    SELECT GF03S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
